@@ -16,8 +16,6 @@
 package metrics
 
 import (
-	"strings"
-
 	dw "github.com/devfile/api/v2/pkg/apis/workspaces/v1alpha2"
 	"github.com/go-logr/logr"
 	"github.com/prometheus/client_golang/prometheus"
@@ -67,31 +65,14 @@ func incrementMetricForWorkspaceFailure(metric *prometheus.CounterVec, wksp *dw.
 	if sourceLabel == "" {
 		sourceLabel = "unknown"
 	}
-	reason := determinateFailureReason(wksp)
-
-	ctr, err := metric.GetMetricWith(map[string]string{metricSourceLabel: sourceLabel, metricsReasonLabel: reason})
+	reason := GetFailureReason(wksp)
+	ctr, err := metric.GetMetricWith(map[string]string{metricSourceLabel: sourceLabel, metricsReasonLabel: string(reason)})
 	if err != nil {
 		log.Error(err, "Failed to increment metric")
 	}
 	ctr.Inc()
 }
 
-// determinateFailureReason scans devworkspace .status.message and try to match
-// it to the know category. Unknown is return when no one is matched
-func determinateFailureReason(wksp *dw.DevWorkspace) string {
-	for _, failure := range badRequestFailures {
-		if strings.Contains(wksp.Status.Message, failure) {
-			return reasonBadRequest
-		}
-	}
-	for _, failure := range infrastructureFailures {
-		if strings.Contains(wksp.Status.Message, failure) {
-			return reasonInfrastructureFailure
-		}
-	}
-	return reasonUnknown
-}
-
 func incrementStartTimeBucketForWorkspace(wksp *dw.DevWorkspace, log logr.Logger) {
 	sourceLabel := wksp.Labels[workspaceSourceLabel]
 	if sourceLabel == "" {
