@@ -25,6 +25,7 @@ import (
 	"time"
 
 	dw "github.com/devfile/api/v2/pkg/apis/workspaces/v1alpha2"
+	"github.com/devfile/devworkspace-operator/pkg/provision/sync"
 
 	"github.com/go-logr/logr"
 	corev1 "k8s.io/api/core/v1"
@@ -36,7 +37,6 @@ import (
 	"github.com/devfile/devworkspace-operator/controllers/workspace/metrics"
 	"github.com/devfile/devworkspace-operator/pkg/conditions"
 	"github.com/devfile/devworkspace-operator/pkg/config"
-	wsprovision "github.com/devfile/devworkspace-operator/pkg/provision/workspace"
 )
 
 const (
@@ -113,15 +113,17 @@ func syncConditions(workspaceStatus *dw.DevWorkspaceStatus, currentStatus *curre
 				workspaceStatus.Conditions[idx].LastTransitionTime = currTransitionTime
 				workspaceStatus.Conditions[idx].Status = corev1.ConditionUnknown
 				workspaceStatus.Conditions[idx].Message = ""
+				workspaceStatus.Conditions[idx].Reason = ""
 			}
 			continue
 		}
 
 		// Update condition if needed
-		if workspaceCondition.Status != currCondition.Status || workspaceCondition.Message != currCondition.Message {
+		if workspaceCondition.Status != currCondition.Status || workspaceCondition.Message != currCondition.Message || workspaceCondition.Reason != currCondition.Reason {
 			workspaceStatus.Conditions[idx].LastTransitionTime = currTransitionTime
 			workspaceStatus.Conditions[idx].Status = currCondition.Status
 			workspaceStatus.Conditions[idx].Message = currCondition.Message
+			workspaceStatus.Conditions[idx].Reason = currCondition.Reason
 		}
 	}
 
@@ -136,6 +138,7 @@ func syncConditions(workspaceStatus *dw.DevWorkspaceStatus, currentStatus *curre
 			Type:               condType,
 			Status:             cond.Status,
 			Message:            cond.Message,
+			Reason:             cond.Reason,
 		})
 	}
 
@@ -145,7 +148,7 @@ func syncConditions(workspaceStatus *dw.DevWorkspaceStatus, currentStatus *curre
 	})
 }
 
-func syncWorkspaceMainURL(workspace *dw.DevWorkspace, exposedEndpoints map[string]v1alpha1.ExposedEndpointList, clusterAPI wsprovision.ClusterAPI) (ok bool, err error) {
+func syncWorkspaceMainURL(workspace *dw.DevWorkspace, exposedEndpoints map[string]v1alpha1.ExposedEndpointList, clusterAPI sync.ClusterAPI) (ok bool, err error) {
 	mainUrl := getMainUrl(exposedEndpoints)
 
 	if workspace.Status.MainUrl == mainUrl {
@@ -172,12 +175,8 @@ func checkServerStatus(workspace *dw.DevWorkspace) (ok bool, err error) {
 	if err != nil {
 		return false, err
 	}
-	if resp.StatusCode == 401 || resp.StatusCode == 403 {
-		// Assume endpoint is unimplemented and * is covered with authentication.
-		return true, nil
-	}
-	if resp.StatusCode == 404 {
-		// Compatibility: assume endpoint is unimplemented.
+	if (resp.StatusCode / 100) == 4 {
+		// Assume endpoint is unimplemented and/or * is covered with authentication.
 		return true, nil
 	}
 	ok = (resp.StatusCode / 100) == 2
