@@ -19,11 +19,11 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/devfile/devworkspace-operator/pkg/constants"
+	"github.com/devfile/devworkspace-operator/pkg/provision/sync"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
-
-	wsprovision "github.com/devfile/devworkspace-operator/pkg/provision/workspace"
 )
 
 const (
@@ -37,8 +37,9 @@ func getSSHAuthorizedKeysConfigMapSpec(namespace string, authorizedKeys []byte)
 			Name:      sshAuthorizedKeysConfigMapName,
 			Namespace: namespace,
 			Labels: map[string]string{
-				"app.kubernetes.io/name":    "async-storage", // TODO
-				"app.kubernetes.io/part-of": "devworkspace-operator",
+				"app.kubernetes.io/name":                  "async-storage", // TODO
+				"app.kubernetes.io/part-of":               "devworkspace-operator",
+				constants.DevWorkspaceWatchConfigMapLabel: "true",
 			},
 		},
 		Data: map[string]string{
@@ -48,7 +49,7 @@ func getSSHAuthorizedKeysConfigMapSpec(namespace string, authorizedKeys []byte)
 	return cm
 }
 
-func getSSHAuthorizedKeysConfigMapCluster(namespace string, clusterAPI wsprovision.ClusterAPI) (*corev1.ConfigMap, error) {
+func getSSHAuthorizedKeysConfigMapCluster(namespace string, clusterAPI sync.ClusterAPI) (*corev1.ConfigMap, error) {
 	cm := &corev1.ConfigMap{}
 	namespaceName := types.NamespacedName{
 		Name:      sshAuthorizedKeysConfigMapName,
