@@ -1,13 +1,16 @@
 //
 // Copyright (c) 2019-2021 Red Hat, Inc.
-// This program and the accompanying materials are made
-// available under the terms of the Eclipse Public License 2.0
-// which is available at https://www.eclipse.org/legal/epl-2.0/
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
 //
-// SPDX-License-Identifier: EPL-2.0
+//     http://www.apache.org/licenses/LICENSE-2.0
 //
-// Contributors:
-//   Red Hat, Inc. - initial API and implementation
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 //
 
 package webhook
@@ -16,18 +19,19 @@ import (
 	"context"
 	"fmt"
 
-	webhookCfg "github.com/devfile/devworkspace-operator/webhook/workspace"
-	"k8s.io/api/admissionregistration/v1beta1"
+	admregv1 "k8s.io/api/admissionregistration/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"sigs.k8s.io/controller-runtime/pkg/client"
+
+	webhookCfg "github.com/devfile/devworkspace-operator/webhook/workspace"
 )
 
 var webhooksCreationTimestamp = metav1.Time{}
 
 func GetWebhooksCreationTimestamp(client client.Client) (metav1.Time, error) {
 	if webhooksCreationTimestamp.IsZero() {
-		webhook := &v1beta1.MutatingWebhookConfiguration{}
+		webhook := &admregv1.MutatingWebhookConfiguration{}
 		err := client.Get(context.TODO(), types.NamespacedName{Name: webhookCfg.MutateWebhookCfgName}, webhook)
 		if err != nil {
 			return metav1.Time{}, fmt.Errorf("failed to get webhook: %w", err)
